@@ -204,6 +204,8 @@ LOCATIONS = {
 LENGTHS = {
     '4': {'value': 4,
           'type': 'point'},
+    '5': {'value': 5,
+          'type': 'point'},
     '6': {'value': 6,
           'type': 'point'},
     '10': {'value': 10,
@@ -350,6 +352,39 @@ VARIANTS = {
         'source': 'reference',
         'location': LOCATIONS['10_11'],
         'inserted': INSERTED['[T;10_20inv;NM_000001.1:c.200_300]']},
+    '10_11ins[CAG[19]CAA[4]]': {'type': 'insertion',
+                                'source': 'reference',
+                                'location':  LOCATIONS['10_11'],
+                                'inserted': [{'sequence': 'CAG',
+                                              'source': 'description',
+                                              'repeat_number': LENGTHS['19']},
+                                             {'sequence': 'CAA',
+                                              'source': 'description',
+                                              'repeat_number': LENGTHS['4']}]},
+    '10_11ins[CAG[19]CAA[4]10_20[19]]': {'type': 'insertion',
+                                         'source': 'reference',
+                                         'location':  LOCATIONS['10_11'],
+                                         'inserted': [{'sequence': 'CAG',
+                                                       'source': 'description',
+                                                       'repeat_number': LENGTHS['19']},
+                                                      {'sequence': 'CAA',
+                                                       'source': 'description',
+                                                       'repeat_number': LENGTHS['4']},
+                                                      {'location':  LOCATIONS['10_20'],
+                                                       'source': 'reference',
+                                                       'repeat_number': LENGTHS['19']}]},
+    '10_11ins[CAG[19]10_20[19]CAA[4]]': {'type': 'insertion',
+                                         'source': 'reference',
+                                         'location':  LOCATIONS['10_11'],
+                                         'inserted': [{'sequence': 'CAG',
+                                                       'source': 'description',
+                                                       'repeat_number': LENGTHS['19']},
+                                                      {'location':  LOCATIONS['10_20'],
+                                                       'source': 'reference',
+                                                       'repeat_number': LENGTHS['19']},
+                                                      {'sequence': 'CAA',
+                                                       'source': 'description',
+                                                       'repeat_number': LENGTHS['4']}]},
     '10_11insNM_000001.1:c.100_200': {
         'type': 'insertion',
         'source': 'reference',
@@ -410,23 +445,168 @@ VARIANTS = {
                               'source': 'reference',
                               'location': LOCATIONS['10_11'],
                               'inserted': INSERTED['R2:g.10_15']},
+    '123_191delinsCAG[19]CAA[4]': {'type': 'deletion_insertion',
+                                   'source': 'reference',
+                                   'location': LOCATIONS['123_191'],
+                                   'inserted': [{'sequence': 'CAG',
+                                                 'source': 'description',
+                                                 'repeat_number':
+                                                     LENGTHS['19']},
+                                                {'sequence': 'CAA',
+                                                 'source': 'description',
+                                                 'repeat_number':
+                                                     LENGTHS['4']}]},
+    '123_191delinsCAG[19]invCAA[4]inv': {'type': 'deletion_insertion',
+                                         'source': 'reference',
+                                         'location': LOCATIONS['123_191'],
+                                         'inserted': [{'sequence': 'CAG',
+                                                       'source': 'description',
+                                                       'repeat_number':
+                                                           LENGTHS['19'],
+                                                       'inverted': True},
+                                                      {'sequence': 'CAA',
+                                                       'source': 'description',
+                                                       'repeat_number':
+                                                           LENGTHS['4'],
+                                                       'inverted': True}]},
+    '123_191delins[CAG[19]CAA[4]]': {'type': 'deletion_insertion',
+                                     'source': 'reference',
+                                     'location':  LOCATIONS['123_191'],
+                                     'inserted': [{'sequence': 'CAG',
+                                                   'source': 'description',
+                                                   'repeat_number':
+                                                       LENGTHS['19']},
+                                                  {'sequence': 'CAA',
+                                                   'source': 'description',
+                                                   'repeat_number':
+                                                       LENGTHS['4']}]},
+    '123_191delins[CAG[19];CAA[4]]': {'type': 'deletion_insertion',
+                                      'source': 'reference',
+                                      'location':  LOCATIONS['123_191'],
+                                      'inserted': [{'sequence': 'CAG',
+                                                    'source': 'description',
+                                                    'repeat_number':
+                                                        LENGTHS['19']},
+                                                   {'sequence': 'CAA',
+                                                    'source': 'description',
+                                                    'repeat_number':
+                                                        LENGTHS['4']}]},
     # Repeats
     '10GA[20]': {'type': 'repeat',
                  'source': 'reference',
                  'location': LOCATIONS['10'],
                  'inserted': [{'sequence': 'GA',
-                               'length': LENGTHS['20']}]},
+                               'source': 'description',
+                               'repeat_number': LENGTHS['20']}]},
     '123_191CAG[19]CAA[4]': {'type': 'repeat',
                              'source': 'reference',
                              'location':  LOCATIONS['123_191'],
                              'inserted': [{'sequence': 'CAG',
-                                           'length': LENGTHS['19']},
+                                           'source': 'description',
+                                           'repeat_number':
+                                               LENGTHS['19']},
                                           {'sequence': 'CAA',
-                                           'length': LENGTHS['4']}]},
+                                           'source': 'description',
+                                           'repeat_number':
+                                               LENGTHS['4']}]},
+    '123_191CAG[19]invCAA[4]inv': {'type': 'repeat',
+                                   'source': 'reference',
+                                   'location':  LOCATIONS['123_191'],
+                                   'inserted': [{'sequence': 'CAG',
+                                                 'source': 'description',
+                                                 'repeat_number':
+                                                     LENGTHS['19'],
+                                                 'inverted': True},
+                                                {'sequence': 'CAA',
+                                                 'source': 'description',
+                                                 'repeat_number':
+                                                     LENGTHS['4'],
+                                                 'inverted': True}]},
+    '123_191C[19]A[4]T[5]': {'type': 'repeat',
+                             'source': 'reference',
+                             'location':  LOCATIONS['123_191'],
+                             'inserted': [{'sequence': 'C',
+                                           'source': 'description',
+                                           'repeat_number':
+                                               LENGTHS['19']},
+                                          {'sequence': 'A',
+                                           'source': 'description',
+                                           'repeat_number':
+                                               LENGTHS['4']},
+                                          {'sequence': 'T',
+                                           'source': 'description',
+                                           'repeat_number':
+                                               LENGTHS['5']}]},
+    '123_191C[19]10_20[19]A[4]T[5]': {'type': 'repeat',
+                                      'source': 'reference',
+                                      'location':  LOCATIONS['123_191'],
+                                      'inserted': [{'sequence': 'C',
+                                                    'source': 'description',
+                                                    'repeat_number':
+                                                        LENGTHS['19']},
+                                                   {'location': LOCATIONS['10_20'],
+                                                    'source': 'reference',
+                                                    'repeat_number':
+                                                        LENGTHS['19']},
+                                                   {'sequence': 'A',
+                                                    'source': 'description',
+                                                    'repeat_number':
+                                                        LENGTHS['4']},
+                                                   {'sequence': 'T',
+                                                    'source': 'description',
+                                                    'repeat_number':
+                                                        LENGTHS['5']}]},
+    '123_191[CAG[19];CAA[4]]': {'type': 'repeat',
+                                'source': 'reference',
+                                'location':  LOCATIONS['123_191'],
+                                'inserted': [{'sequence': 'CAG',
+                                              'source': 'description',
+                                              'repeat_number':
+                                                  LENGTHS['19']},
+                                             {'sequence': 'CAA',
+                                              'source': 'description',
+                                              'repeat_number':
+                                                  LENGTHS['4']}]},
+    '123_191[CAG[19];CAA[4];10_15[6]]': {'type': 'repeat',
+                                         'source': 'reference',
+                                         'location':  LOCATIONS['123_191'],
+                                         'inserted': [{'sequence': 'CAG',
+                                                       'source': 'description',
+                                                       'repeat_number':
+                                                           LENGTHS['19']},
+                                                      {'sequence': 'CAA',
+                                                       'source': 'description',
+                                                       'repeat_number':
+                                                           LENGTHS['4']},
+                                                      {'location':
+                                                           LOCATIONS['10_15'],
+                                                       'source': 'reference',
+                                                       'repeat_number':
+                                                           LENGTHS['6']}]},
+    '123_191[CAG[19];CAA[4]inv;10_15[6]inv]': {'type': 'repeat',
+                                               'source': 'reference',
+                                               'location':
+                                                   LOCATIONS['123_191'],
+                                               'inserted':
+                                                   [{'sequence': 'CAG',
+                                                     'source': 'description',
+                                                     'repeat_number':
+                                                         LENGTHS['19']},
+                                                    {'sequence': 'CAA',
+                                                     'source': 'description',
+                                                     'repeat_number':
+                                                         LENGTHS['4'],
+                                                     'inverted': True},
+                                                    {'location':
+                                                         LOCATIONS['10_15'],
+                                                     'source': 'reference',
+                                                     'repeat_number':
+                                                         LENGTHS['6'],
+                                                     'inverted': True}]},
     # No changes (equal)
     # '=': [],
-    '10=': {'type': 'equal'
-        ,'source': 'reference',
+    '10=': {'type': 'equal',
+            'source': 'reference',
             'location': LOCATIONS['10']},
     '10_20=': {'type': 'equal',
                'source': 'reference',
